@@ -52,13 +52,13 @@
 #include <views/viewproperties.h>
 
 #ifdef HAVE_NEPOMUK
-    #include <Nepomuk/ResourceManager>
-    #include <Nepomuk/Query/ComparisonTerm>
-    #include <Nepomuk/Query/LiteralTerm>
-    #include <Nepomuk/Query/FileQuery>
-    #include <Nepomuk/Query/ResourceTypeTerm>
-    #include <Nepomuk/Vocabulary/NFO>
-    #include <Nepomuk/Vocabulary/NIE>
+    #include <Nepomuk2/ResourceManager>
+    #include <Nepomuk2/Query/ComparisonTerm>
+    #include <Nepomuk2/Query/LiteralTerm>
+    #include <Nepomuk2/Query/FileQuery>
+    #include <Nepomuk2/Query/ResourceTypeTerm>
+    #include <Nepomuk2/Vocabulary/NFO>
+    #include <Nepomuk2/Vocabulary/NIE>
 #endif
 
 namespace {
@@ -88,7 +88,7 @@ PlacesItemModel::PlacesItemModel(QObject* parent) :
     m_storageSetupInProgress()
 {
 #ifdef HAVE_NEPOMUK
-    if (Nepomuk::ResourceManager::instance()->initialized()) {
+    if (Nepomuk2::ResourceManager::instance()->initialized()) {
         KConfig config("nepomukserverrc");
         m_fileIndexingEnabled = config.group("Service-nepomukfileindexer").readEntry("autostart", false);
     }
@@ -578,14 +578,14 @@ void PlacesItemModel::slotDeviceRemoved(const QString& udi)
             delete item;
             return;
         }
-     }
+    }
 
-     for (int i = 0; i < count(); ++i) {
-         if (placesItem(i)->udi() == udi) {
-             removeItem(i);
-             return;
-         }
-     }
+    for (int i = 0; i < count(); ++i) {
+        if (placesItem(i)->udi() == udi) {
+            removeItem(i);
+            return;
+        }
+    }
 }
 
 void PlacesItemModel::slotStorageTeardownDone(Solid::ErrorType error, const QVariant& errorData)
@@ -900,8 +900,6 @@ void PlacesItemModel::createSystemBookmarks()
     Q_ASSERT(m_systemBookmarks.isEmpty());
     Q_ASSERT(m_systemBookmarksIndexes.isEmpty());
 
-    const QString timeLineIcon = "chronometer";
-
     // Note: The context of the I18N_NOOP2 must be "KFile System Bookmarks". The real
     // i18nc call is done after reading the bookmark. The reason why the i18nc call is not
     // done here is because otherwise switching the language would not result in retranslating the
@@ -921,16 +919,16 @@ void PlacesItemModel::createSystemBookmarks()
 
     if (m_fileIndexingEnabled) {
         m_systemBookmarks.append(SystemBookmarkData(KUrl("timeline:/today"),
-                                                    timeLineIcon,
+                                                    "go-jump-today",
                                                     I18N_NOOP2("KFile System Bookmarks", "Today")));
         m_systemBookmarks.append(SystemBookmarkData(KUrl("timeline:/yesterday"),
-                                                    timeLineIcon,
+                                                    "view-calendar-day",
                                                     I18N_NOOP2("KFile System Bookmarks", "Yesterday")));
         m_systemBookmarks.append(SystemBookmarkData(KUrl("timeline:/thismonth"),
-                                                    timeLineIcon,
+                                                    "view-calendar-month",
                                                     I18N_NOOP2("KFile System Bookmarks", "This Month")));
         m_systemBookmarks.append(SystemBookmarkData(KUrl("timeline:/lastmonth"),
-                                                    timeLineIcon,
+                                                    "view-calendar-month",
                                                     I18N_NOOP2("KFile System Bookmarks", "Last Month")));
         m_systemBookmarks.append(SystemBookmarkData(KUrl("search:/documents"),
                                                     "folder-txt",
@@ -1161,15 +1159,15 @@ KUrl PlacesItemModel::createSearchUrl(const KUrl& url)
 #ifdef HAVE_NEPOMUK
     const QString path = url.pathOrUrl();
     if (path.endsWith(QLatin1String("documents"))) {
-        searchUrl = searchUrlForTerm(Nepomuk::Query::ResourceTypeTerm(Nepomuk::Vocabulary::NFO::Document()));
+        searchUrl = searchUrlForTerm(Nepomuk2::Query::ResourceTypeTerm(Nepomuk2::Vocabulary::NFO::Document()));
     } else if (path.endsWith(QLatin1String("images"))) {
-        searchUrl = searchUrlForTerm(Nepomuk::Query::ResourceTypeTerm(Nepomuk::Vocabulary::NFO::Image()));
+        searchUrl = searchUrlForTerm(Nepomuk2::Query::ResourceTypeTerm(Nepomuk2::Vocabulary::NFO::Image()));
     } else if (path.endsWith(QLatin1String("audio"))) {
-        searchUrl = searchUrlForTerm(Nepomuk::Query::ComparisonTerm(Nepomuk::Vocabulary::NIE::mimeType(),
-                                                                    Nepomuk::Query::LiteralTerm("audio")));
+        searchUrl = searchUrlForTerm(Nepomuk2::Query::ComparisonTerm(Nepomuk2::Vocabulary::NIE::mimeType(),
+                                                                    Nepomuk2::Query::LiteralTerm("audio")));
     } else if (path.endsWith(QLatin1String("videos"))) {
-        searchUrl = searchUrlForTerm(Nepomuk::Query::ComparisonTerm(Nepomuk::Vocabulary::NIE::mimeType(),
-                                                                    Nepomuk::Query::LiteralTerm("video")));
+        searchUrl = searchUrlForTerm(Nepomuk2::Query::ComparisonTerm(Nepomuk2::Vocabulary::NIE::mimeType(),
+                                                                    Nepomuk2::Query::LiteralTerm("video")));
     } else {
         Q_ASSERT(false);
     }
@@ -1181,9 +1179,9 @@ KUrl PlacesItemModel::createSearchUrl(const KUrl& url)
 }
 
 #ifdef HAVE_NEPOMUK
-KUrl PlacesItemModel::searchUrlForTerm(const Nepomuk::Query::Term& term)
+KUrl PlacesItemModel::searchUrlForTerm(const Nepomuk2::Query::Term& term)
 {
-    const Nepomuk::Query::FileQuery query(term);
+    const Nepomuk2::Query::FileQuery query(term);
     return query.toSearchUrl();
 }
 #endif
