@@ -483,6 +483,12 @@ signals:
      */
     void directoryLoadingCompleted();
 
+    /**
+     * Is emitted after the directory loading triggered by DolphinView::setUrl()
+     * has been canceled.
+     */
+    void directoryLoadingCanceled();
+
     /**
      * Is emitted after DolphinView::setUrl() has been invoked and provides
      * the information how much percent of the current directory have been loaded.
@@ -759,7 +765,6 @@ private:
     QPoint m_restoredContentsPosition;
 
     QList<KUrl> m_selectedUrls; // Used for making the view to remember selections after F5
-    bool m_clearSelectionBeforeSelectingNewItems;
 
     VersionControlObserver* m_versionControlObserver;
 
