@@ -631,8 +631,6 @@ void FolderView::configChanged()
 
 FolderView::~FolderView()
 {
-    if (m_dialog)
-        delete m_dialog;
     delete m_newMenu;
 }
 
@@ -1246,6 +1244,7 @@ void FolderView::constraintsEvent(Plasma::Constraints constraints)
 
             delete m_iconWidget;
             delete m_dialog;
+            delete m_listView;
             m_iconWidget = 0;
             m_dialog = 0;
             m_listView = 0;
@@ -1273,7 +1272,7 @@ void FolderView::constraintsEvent(Plasma::Constraints constraints)
             // Set up the icon widget
             m_iconWidget = new IconWidget(this);
             m_iconWidget->setModel(m_dirModel);
-            m_iconWidget->setIcon(m_icon.isNull() ? KIcon("user-folder") : m_icon);
+            m_iconWidget->setIcon(m_icon.isNull() ? KIcon("folder-blue") : m_icon);
             connect(m_iconWidget, SIGNAL(clicked()), SLOT(iconWidgetClicked()));
 
             updateIconWidget();
@@ -2065,7 +2064,7 @@ void FolderView::updateIconWidget()
     } else if (index.isValid()) {
         m_icon = m_placesModel->icon(index);
     } else {
-        m_icon = KIcon("user-folder");
+        m_icon = KIcon("folder-blue");
     }
 
     m_iconWidget->setIcon(m_icon);
